local ADDON_NAME, addonTable = ...

local ElkExperience = LibStub("AceAddon-3.0"):GetAddon("ElkExperience")
local cfgreg = LibStub("AceConfigRegistry-3.0")

local optionsTable = {
	type = "group",
	args = {
		genericSettings = {
			name = "Generic Settings",
			order = 1,
			type = "group",
			inline = true,
			args = {
				minimapButtonEnabled = {
					name = "Show Minimap Button",
					type = "toggle",
					get = function(info)
							return not ElkExperience.db.profile.minimap.hide
						end,
					set = function(info, value)
							ElkExperience.db.profile.minimap.hide = not value
							LibStub("LibDBIcon-1.0"):Refresh("ElkExperience")
						end
				},
			},
		},
		textPatterns = {
			name = "Text Patterns",
			order = 2,
			type = "group",
			inline = true,
			args = {
				patternText = {
					name = "Pattern (Data Object Text)",
					order = 1,
					type = "input",
					width = "double",
				},
				patternTextRested = {
					name = "Pattern - Rested (Data Object Text)",
					order = 2,
					type = "input",
					width = "double",
				},
				patternChat = {
					name = "Pattern (Chat Inserts)",
					order = 3,
					type = "input",
					width = "double",
				},
				patternChatRested = {
					name = "Pattern - Rested (Chat Inserts)",
					order = 4,
					type = "input",
					width = "double",
				},
				patternDesc01 = {
					name = "Different placeholders are available:",
					order = 51,
					type = "description",
				},
				patternDesc02 = {
					name = [[
{pl}   player level
{lm}   XP max for current level
{lc}   XP gained on current level
{lr}   XP missing on current level
{lcp}  percentage of level XP gained
{lrp}  percentage of level XP missing
{s}    XP gained this session
{rc}   rested current
{rp}   rested percent
{last} last XP gain
{phl}  XP/h level
{phs}  XP/h session
{tl}   time until level up based on level's rate
{ts}   time until level up based on session's rate
{kl}   kills needed based on last XP gain]],
					order = 52,
					type = "description",
				},
			},
			get = function(info)
					return ElkExperience.db.profile[info[#info]]
				end,
			set = function(info, value)
					if value == "" then value = nil end
					ElkExperience.db.profile[info[#info]] = value
					ElkExperience:UpdateText()
				end,
		},
	},
}
LibStub("AceConfigRegistry-3.0"):RegisterOptionsTable("ElkExperience", optionsTable)
